@@ -5,7 +5,7 @@ import scipy
 import flammkuchen
 import numpy as np
 from . import utils, data, models, event_utils, segment_utils, annot
-from typing import List, Optional, Dict, Any, Sequence, Union
+from typing import List, Optional, Dict, Any, Sequence
 import glob
 import tensorflow
 import zarr
@@ -371,7 +371,7 @@ def predict_events(class_probabilities: np.ndarray,
 
 
 def predict_song(class_probabilities: np.ndarray,
-                 params: dict[str, Any],
+                 params: Dict[str, Any],
                  event_thres: float = 0.5,
                  event_dist: float = 0.01,
                  event_dist_min: float = 0,
@@ -410,7 +410,7 @@ def predict(x: np.ndarray,
             verbose: int = 1,
             batch_size: int = None,
             model: models.keras.models.Model = None,
-            params: dict = None,
+            params: Dict = None,
             event_thres: float = 0.5,
             event_dist: float = 0.01,
             event_dist_min: float = 0,
